aboutsummaryrefslogtreecommitdiff
path: root/gdb/solib-aix.c
diff options
context:
space:
mode:
authorSimon Marchi <simon.marchi@efficios.com>2023-10-17 15:37:58 -0400
committerSimon Marchi <simon.marchi@efficios.com>2023-10-19 11:14:26 -0400
commit3fe0dfd1604f9bf8d51a7473f7f27e16242986be (patch)
tree29cbbacf6997fd331d8d383de4546f0482bd87a2 /gdb/solib-aix.c
parent30932f40120fa64147f8b5f7d9e4c462825c4e47 (diff)
downloadgdb-3fe0dfd1604f9bf8d51a7473f7f27e16242986be.zip
gdb-3fe0dfd1604f9bf8d51a7473f7f27e16242986be.tar.gz
gdb-3fe0dfd1604f9bf8d51a7473f7f27e16242986be.tar.bz2
gdb: rename struct so_list to shobj
Now that so_list lists are implemented using intrusive_list, it doesn't really make sense for the element type to be named "_list". Rename to just `struct shobj` (`struct so` was deemed to be not greppable enough). Change-Id: I1063061901298bb40fee73bf0cce44cd12154c0e Approved-By: Pedro Alves <pedro@palves.net> Reviewed-By: Reviewed-By: Lancelot Six <lancelot.six@amd.com>
Diffstat (limited to 'gdb/solib-aix.c')
-rw-r--r--gdb/solib-aix.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/gdb/solib-aix.c b/gdb/solib-aix.c
index 68798e8..c8fa865 100644
--- a/gdb/solib-aix.c
+++ b/gdb/solib-aix.c
@@ -26,7 +26,7 @@
#include "xcoffread.h"
#include "observable.h"
/* Our private data in struct so_list. */
struct lm_info_aix final : public lm_info
{
@@ -311,7 +311,7 @@ solib_aix_bss_data_overlap (bfd *abfd)
/* Implement the "relocate_section_addresses" target_so_ops method. */
static void
-solib_aix_relocate_section_addresses (so_list &so, target_section *sec)
+solib_aix_relocate_section_addresses (shobj &so, target_section *sec)
{
struct bfd_section *bfd_sect = sec->the_bfd_section;
bfd *abfd = bfd_sect->owner;
@@ -445,7 +445,7 @@ solib_aix_solib_create_inferior_hook (int from_tty)
/* Implement the "current_sos" target_so_ops method. */
-static intrusive_list<so_list>
+static intrusive_list<shobj>
solib_aix_current_sos ()
{
gdb::optional<std::vector<lm_info_aix>> &library_list
@@ -453,14 +453,14 @@ solib_aix_current_sos ()
if (!library_list.has_value ())
return {};
- intrusive_list<so_list> sos;
+ intrusive_list<shobj> sos;
- /* Build a struct so_list for each entry on the list.
+ /* Build a struct shobj for each entry on the list.
We skip the first entry, since this is the entry corresponding
to the main executable, not a shared library. */
for (int ix = 1; ix < library_list->size (); ix++)
{
- so_list *new_solib = new so_list;
+ shobj *new_solib = new shobj;
std::string so_name;
lm_info_aix &info = (*library_list)[ix];
@@ -26,7 +26,7 @@
#include "xcoffread.h"
#include "observable.h"
-/* Our private data in struct so_list. */
+/* Our private data in struct shobj. */
struct lm_info_aix final : public lm_info
{